==> pure-store-1.0.2.tgz: package/react.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import { PureStore } from "./index";
var PureStoreReact = /** @class */ (function (_super) {
    __extends(PureStoreReact, _super);
    function PureStoreReact() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PureStoreReact.prototype.usePureStore = function (getter) {
        var _this = this;
        if (getter) {
            return new PureStoreReact(this, getter).usePureStore();
        }
        var _a = React.useState(this.getState()), _ = _a[0], setState = _a[1];
        React.useEffect(function () {
            _this.subscribe(function () { return setState(_this.getState()); });
        }, []);
        return [this.getState(), this.update];
    };
    return PureStoreReact;
}(PureStore));
export default (function (state) { return (new PureStoreReact(null, function (s) { return s; }, state)); });
export { PureStoreReact as PureStore };

==> pure-store-1.2.0.tgz: package/react.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import { PureStore } from "./index";
var PureStoreReact = /** @class */ (function (_super) {
    __extends(PureStoreReact, _super);
    function PureStoreReact() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PureStoreReact.prototype.usePureStore = function (getter) {
        var _this = this;
        if (getter) {
            return new PureStoreReact(this, getter).usePureStore();
        }
        var _a = React.useState(this.getState()), _ = _a[0], setState = _a[1];
        React.useEffect(function () {
            return _this.subscribe(function () { return setState(_this.getState()); });
        }, []);
        return [this.getState(), this.update];
    };
    return PureStoreReact;
}(PureStore));
export default (function (state) { return (new PureStoreReact(null, function (s) { return s; }, state)); });
export { PureStoreReact as PureStore };
